@@ -3,7 +3,7 @@
 # by Eriberto
 # Create the manpage using txt2man command.
 
-T2M_DATE="11 Nov 2017"
+T2M_DATE="04 Dec 2022"
 T2M_NAME=iwatch
 T2M_VERSION=0.2.2
 T2M_LEVEL=1
